lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [lmi] master 8fc8f97 4/6: Rename a member function


From: Greg Chicares
Subject: [lmi-commits] [lmi] master 8fc8f97 4/6: Rename a member function
Date: Tue, 12 Jun 2018 17:50:20 -0400 (EDT)

branch: master
commit 8fc8f97825b6a46feafa28869d603a5cf0eae7c4
Author: Gregory W. Chicares <address@hidden>
Commit: Gregory W. Chicares <address@hidden>

    Rename a member function
    
    There are now two "Paste" functions, so both should be suffixed.
---
 census_view.cpp | 8 ++++----
 census_view.hpp | 2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/census_view.hpp b/census_view.hpp
index 63e00fa..5dcb8a1 100644
--- a/census_view.hpp
+++ b/census_view.hpp
@@ -72,7 +72,7 @@ class CensusView final
     void UponEditCase               (wxCommandEvent&);
     void UponColumnWidthVarying     (wxCommandEvent&);
     void UponColumnWidthFixed       (wxCommandEvent&);
-    void UponPasteCensus            (wxCommandEvent&);
+    void UponPasteCensusIn          (wxCommandEvent&);
     void UponPasteCensusOut         (wxCommandEvent&) const;
     void UponRightClick             (wxDataViewEvent&);
     void UponPrintCase              (wxCommandEvent&);



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/census_view.cpp b/census_view.cpp
index f448e31..b8f502c 100644
--- a/census_view.cpp
+++ b/census_view.cpp
@@ -861,7 +861,7 @@ BEGIN_EVENT_TABLE(CensusView, ViewEx)
     EVT_MENU(XRCID("print_spreadsheet"         
),CensusView::UponRunCaseToSpreadsheet   )
     EVT_MENU(XRCID("print_group_roster"        
),CensusView::UponRunCaseToGroupRoster   )
     EVT_MENU(XRCID("print_group_quote"         
),CensusView::UponRunCaseToGroupQuote    )
-    EVT_MENU(XRCID("paste_census"              ),CensusView::UponPasteCensus   
         )
+    EVT_MENU(XRCID("paste_census"              ),CensusView::UponPasteCensusIn 
         )
     EVT_MENU(XRCID("add_cell"                  ),CensusView::UponAddCell       
         )
     EVT_MENU(XRCID("delete_cells"              ),CensusView::UponDeleteCells   
         )
     EVT_MENU(XRCID("column_width_varying"      
),CensusView::UponColumnWidthVarying     )
@@ -1604,7 +1604,7 @@ void CensusView::UponRunCaseToGroupQuote(wxCommandEvent&)
 /// file are assumed to represent user intention). In this case,
 /// pasted data is appended to the cells that were already present.
 
-void CensusView::UponPasteCensus(wxCommandEvent&)
+void CensusView::UponPasteCensusIn(wxCommandEvent&)
 {
     std::string const census_data = ClipboardEx::GetText();
 
@@ -1786,7 +1786,7 @@ void CensusView::UponPasteCensus(wxCommandEvent&)
 /// data from lmi, manipulating it in a spreadsheet, and then pasting
 /// it back into lmi.
 ///
 /// Never extract "UseDOB": it's always set by UponPasteCensus().
 /// Never extract "IssueAge". If it's present, then "UseDOB" must also
 /// be, and "UseDOB" preserves information that "IssueAge" loses.
 ///
@@ -1797,7 +1797,7 @@ void CensusView::UponPasteCensus(wxCommandEvent&)
 /// expected; thus, they end in "'t\n". This makes the code slightly
 /// simpler by avoiding a "loop and a half". In practice, it doesn't
 /// make any difference: gnumeric, libreoffice calc, a popular msw
 /// spreadsheet program, and lmi's own UponPasteCensus() all ignore
 /// the extra '\t'.
 
 void CensusView::UponPasteCensusOut(wxCommandEvent&) const
@@ -1786,7 +1786,7 @@ void CensusView::UponPasteCensus(wxCommandEvent&)
 /// it back into lmi.
 ///
-/// Never extract "UseDOB": it's always set by UponPasteCensus().
+/// Never extract "UseDOB": it's always set by UponPasteCensusIn().
 /// Never extract "IssueAge". If it's present, then "UseDOB" must also
 /// be, and "UseDOB" preserves information that "IssueAge" loses.
@@ -1797,7 +1797,7 @@ void CensusView::UponPasteCensus(wxCommandEvent&)
 /// simpler by avoiding a "loop and a half". In practice, it doesn't
 /// make any difference: gnumeric, libreoffice calc, a popular msw
-/// spreadsheet program, and lmi's own UponPasteCensus() all ignore
+/// spreadsheet program, and lmi's own UponPasteCensusIn() all ignore
 /// the extra '\t'.
 